pub(crate) enum LoaderEntriesOpts {
SetOptionsForSource(SetOptionsForSourceOpts),
}Expand description
Operations on Boot Loader Specification (BLS) entries.
These commands support managing kernel arguments from multiple independent
sources (e.g., TuneD, admin, bootc kargs.d) by tracking argument ownership
via x-options-source-<name> extension keys in BLS config files.
Variants
SetOptionsForSource(SetOptionsForSourceOpts)
Set or update the kernel arguments owned by a specific source.
Each source’s arguments are tracked via x-options-source-<name>
keys in BLS config files. The options line is recomputed as the
merge of all tracked sources plus any untracked (pre-existing) options.
This stages a new deployment with the updated kernel arguments.
Examples
Add TuneD kernel arguments: bootc loader-entries set-options-for-source –source tuned –options “isolcpus=1-3 nohz_full=1-3”
Update TuneD kernel arguments: bootc loader-entries set-options-for-source –source tuned –options “isolcpus=0-7”
Remove TuneD kernel arguments: bootc loader-entries set-options-for-source –source tuned