pub async fn run_from_iter<I>(args: I) -> Result<CliExitStatus>Expand description
Parse the provided arguments and execute.
Calls [clap::Error::exit] on failure, printing the error message and aborting the program.
pub async fn run_from_iter<I>(args: I) -> Result<CliExitStatus>Parse the provided arguments and execute.
Calls [clap::Error::exit] on failure, printing the error message and aborting the program.