pub(crate) struct SetOptionsForSourceOpts {
pub(crate) source: String,
pub(crate) options: Option<String>,
}Expand description
Options for the set-options-for-source subcommand.
Fields
source: StringThe name of the source that owns these kernel arguments.
Must contain only alphanumeric characters, hyphens, or underscores. Examples: “tuned”, “admin”, “bootc-kargs-d”
options: Option<String>The kernel arguments to set for this source.
If not provided, the source is removed and its options are
dropped from the merged options line.